@@ -1,5 +1,3 @@
-package org.apache.maven.it0055;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.apache.maven.it0055;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,19 +16,16 @@ package org.apache.maven.it0055;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.it0055;
 
-
-public class Person
-{
+public class Person {
     private String name;
-    
-    public void setName( String name )
-    {
+
+    public void setName(String name) {
         this.name = name;
     }
-    
-    public String getName()
-    {
+
+    public String getName() {
         return name;
     }
 }
