@@ -17,7 +17,6 @@
  * under the License.
  */
 
-module foo
-{
+module foo {
     requires org.apache.commons.lang3;
 }
