@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -16,14 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+package foo;
 
-public class MyTest
-{
+public class MyTest {
 
-    public static void main( String[] args )
-    {
+    public static void main(String[] args) {
         // the date constructor is deprecated and will cause a warning
-        System.out.println( new java.util.Date( 2010, 8, 29 ) );
+        System.out.println(new java.util.Date(2010, 8, 29));
     }
-
 }
