@@ -16,14 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+package foo;
 
 import junit.framework.TestCase;
 
-public class TestCompile0Test
-    extends TestCase
-{
-    public void testCompile0Test()
-    {
+public class TestCompile0Test extends TestCase {
+    public void testCompile0Test() {
         TestCompile0 test = new TestCompile0();
     }
-}
\ No newline at end of file
+}
