@@ -16,14 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+package foo;
 
 import junit.framework.TestCase;
 
-public class TestCompile3TestCase
-    extends TestCase
-{
-    public void testCompile3()
-    {
+public class TestCompile3TestCase extends TestCase {
+    public void testCompile3() {
         TestCompile3 test = new TestCompile3();
     }
-}
\ No newline at end of file
+}
